DataSave class

Constructors

DataSave()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getBool(String key) bool?
getDouble(String key) double?
getInt(String key) int?
getLargeString(String key) String?
Reads a value written with setLargeString.
getString(String key) String?
init() Future<void>
remove(String key) Future<void>
removeAll() Future<void>
removeAllLarge() Future<void>
setBool(String key, bool value) Future<void>
setDouble(String key, double value) Future<void>
setInt(String key, int value) Future<void>
setLargeString(String key, String value) Future<void>
Stores a larger string in localStorage on web and SharedPreferences on native platforms.
setString(String key, String value) Future<void>